Node-liblzma
==========

[![NPM Version](https://img.shields.io/npm/v/node-liblzma.svg)](https://npmjs.org/package/node-liblzma)
[![NPM Downloads](https://img.shields.io/npm/dm/node-liblzma.svg)](https://npmjs.org/package/node-liblzma)
[![Build Status](https://travis-ci.org/oorabona/node-liblzma.png)](https://travis-ci.org/oorabona/node-liblzma)
[![Dependency Status](https://david-dm.org/oorabona/node-liblzma.svg)](https://david-dm.org/oorabona/node-liblzma)
[![devDependency Status](https://david-dm.org/oorabona/node-liblzma/dev-status.svg)](https://david-dm.org/oorabona/node-liblzma#info=devDependencies)

# What is liblzma/XZ ?

[XZ](http://tukaani.org/xz/xz-file-format.txt) is a container for compressed archives. It is among the best compressors out there according to several benchmarks:
* [Gzip vs Bzip2 vs LZMA vs XZ vs LZ4 vs LZO](http://pokecraft.first-world.info/wiki/Quick_Benchmark:_Gzip_vs_Bzip2_vs_LZMA_vs_XZ_vs_LZ4_vs_LZO)
* [Large Text Compression Benchmark](http://mattmahoney.net/dc/text.html#2118)
* [Linux Compression Comparison (GZIP vs BZIP2 vs LZMA vs ZIP vs Compress)](http://bashitout.com/2009/08/30/Linux-Compression-Comparison-GZIP-vs-BZIP2-vs-LZMA-vs-ZIP-vs-Compress.html)

It has a good balance between compression time/ratio and decompression time/memory.

# About this project

This project aims towards providing:
* A quick and easy way to play with XZ compression:
Quick and easy as it conforms to zlib API, so that switching from __zlib/deflate__ to __xz__ might be as easy as a string search/replace in your code editor :smile:

* Complete integration with XZ sources/binaries:
You can either use system packages or download a specific version and compile it!
See [installation](#installation) below.

> Only LZMA2 is supported for compression output.
But the library can open and read any LZMA1 or LZMA2 compressed file. And possibly others...

# What's new ?

Supports all NodeJS versions, thanks to [nan](https://github.com/nodejs/nan) !
It has been tested and works on:
- Linux x64 (Ubuntu)
- OSX (tested with Travis)
- Raspberry Pi 2 (armv7l 32-bits)
- Raspberry Pi 3 (armv8l but still a 32 bits Raspbian)
- Windows (ongoing tests)

# Related projects

Thanks to the community, there are several choices out there:
* [lzma-purejs](https://github.com/cscott/lzma-purejs)
A pure JavaScript implementation of the algorithm
* [node-xz](https://github.com/robey/node-xz)
Node binding of XZ library
* [lzma-native](https://github.com/addaleax/lzma-native)
A very complete implementation of XZ library bindings
* Others are also available but they fork "xz" process in the background.

# API comparison

```js
var lzma = require('lzma');
```

Zlib            | XZlib                   | Arguments
----------------|-------------------------|---------------
createGzip      | createXz                | ([lzma_options, [options]])
createGunzip    | createUnxz              | ([lzma_options, [options]])
gzip            | xz                      | (buf, [options], callback)
gunzip          | unxz                    | (buf, [options], callback)
gzipSync        | xzSync                  | (buf, [options])
gunzipSync      | unxzSync                | (buf, [options])

## Constants

`options` is an `Object` with the following possible attributes:

Attribute            | Type     | Available options
---------------------|----------|------------
check                | Uint32   | NONE
 | |CRC32
 | |CRC64
 | |SHA256
preset | Uint32 | DEFAULT
 | |EXTREME
flag | Uint32 | TELL_NO_CHECK
 | |TELL_UNSUPPORTED_CHECK
 | |TELL_ANY_CHECK
 | |CONCATENATED
mode | Uint32 | FAST
 | |NORMAL
filters | Array | LZMA2 (added by default)
 | |X86
 | |POWERPC
 | |IA64
 | |ARM
 | |ARMTHUMB
 | |SPARC

For further information about each of these flags, you will find reference at [XZ SDK](http://7-zip.org/sdk.html).

# Installation

Well, as simple as this one-liner:

```sh
$ npm i node-liblzma --save
```

If you want to enable threading support in the module, then opt in with:

``` bash
$ ENABLE_MT=1 npm install node-liblzma --save
```

> This will of course work only if you have a binary version of liblzma with threading enabled.
If this is not the case, it will not fail (even at runtime). It justs won't work.
To check if this is enabled or not, run the [tests suite](#tests)

In both cases, it will try to download an existing pre-compiled module binary and if none exists it will build it.

To build the module, you have the following options:
1. Using system development libraries
2. Automatic download and compilation of `xz` libs, and statically link against node module
3. Compile `xz` yourself, outside `node-liblzma` and build node module with dynamically linked library

## Using system dev libraries to compile

You need to have the development package installed on your system. If you have Debian based distro:

```
# apt-get install liblzma-dev
```

## Automatic download and compilation to statically link `xz`

If you do not plan on having a local install, you can ask for automatic download and build of whatever version of `xz` you want.
With the use of [UBS](https://github.com/oorabona/ubs), you do not need to download/configure/install `xz` yourself anymore.

Just do:

```sh
$ COMPILE=1 npm install --save node-liblzma
```

When no option is given in the commandline arguments, it will build with default values.

If you want to build __experimental__ multi-threading feature, you can build `xz` with threads enabled just for this library by running:

```sh
$ ENABLE_MT=1 COMPILE=1 npm install --save node-liblzma
```

## Local install of `xz` sources (outside `node-liblzma`)

So you did install `xz` somewhere outside the module and want the module to use it.

For that, you need to set the include directory and library directory search paths as GCC [environment variables](https://gcc.gnu.org/onlinedocs/gcc/Environment-Variables.html).

```sh
$ export CPATH=$HOME/path/to/headers
$ export LIBRARY_PATH=$HOME/path/to/lib
$ export LD_LIBRARY_PATH=$HOME/path/to/lib:$LD_LIBRARY_PATH
```

The latest is needed for tests to be run right after.

Once done, this should suffice:

```sh
$ npm install
```

# Tests

You can run tests with:

```sh
$ npm test
```

It will build and launch tests suite with [Mocha](https://github.com/visionmedia/mocha).

# Usage

As the API is very close to NodeJS Zlib, you will probably find a good reference
[there](http://www.nodejs.org/api/zlib.html).

Otherwise examples can be found as part of the test suite, so feel free to use them!
They are written in [CoffeeScript](http://www.coffeescript.org).

# Bugs

If you find one, feel free to contribute and post a new issue!
PR are accepted as well :)

Kudos goes to [addaleax](https://github.com/addaleax) for helping me out with C++ stuff !

If you compile with threads, you may see a bunch of warnings about `-Wmissing-field-initializers`.
This is _normal_ and does not prevent threading from being active and working.
I did not yet figure how to fix this except by masking the warning..

# License

This software is released under LGPL3.0+
